/**
 * Plugin to generate a license section.
 *
 * @type {import('unified').Plugin<[Options], Root>}
 */
export default function remarkLicense(
  options?: Options
):
  | void
  | import('unified').Transformer<import('mdast').Root, import('mdast').Root>
export type Root = import('mdast').Root
export type Paragraph = import('mdast').Paragraph
export type Link = import('mdast').Link
export type PhrasingContent = import('mdast').PhrasingContent
/**
 * Configuration (optional).
 */
export type Options = {
  /**
   * License holder.
   * Detected from the `package.json` closest to the file supporting both
   * `object` and `string` format of `author`.
   * *Throws when neither given nor detected.*
   */
  name?: string | undefined
  /**
   * SPDX identifier
   * Detected from the `license` field in the `package.json` in the current
   * working directory.
   * Deprecated license objects are not supported.
   * *Throws when neither given nor detected.*
   */
  license?: string | undefined
  /**
   * File name of license file
   * Detected from the files in the directory of the `package.json` if there is
   * one, or the current working directory, in which case the first file
   * matching `/^licen[cs]e(?=$|\.)/i` is used.
   * If there is no given or found license file, but `options.license` is a
   * known SPDX identifier, the URL to the license on `spdx.org` is used.
   */
  file?: string | undefined
  /**
   * URL to license holder
   * Detected from the `package.json` in the current working directory,
   * supporting both `object` and `string` format of `author`.
   * `http://` is prepended if `url` starts without HTTP or HTTPS protocol.
   */
  url?: string | undefined
  /**
   * Ignore final definitions otherwise in the section.
   */
  ignoreFinalDefinitions?: boolean | undefined
  /**
   * Heading to look for.
   * Default: `/^licen[cs]e$/i`.
   */
  heading?: string | RegExp | undefined
}
